@@ -103,31 +103,34 @@ class BitmexClient:
 
 
 class BitmexOrder:
-    def __init__(self, client, settings, settings_path, magic='algo-trader'):
+    def __init__(self, symbols, client, settings, settings_path, magic='algo-trader'):
         self.client = client
         self.settings = settings
         self._settings_path = settings_path
         self.magic = magic
 
         self.props = {}
+        for symbol in symbols:
+            self.props[symbol] = {
+                'stoploss_id': '', 'entry': .0, 'SL': .0, 'TP': .0, 'open': False, 'qty': 0}
 
     def check_open_bot_order(self, symbol, entry, sl):
         settings = pickle.load(open(self._settings_path, 'rb'))
-        self.props[symbol].stoploss_id = settings.symbols[symbol].last_order_id
-        if self.props[symbol].stoploss_id:
+        self.props[symbol]['stoploss_id'] = settings.symbols[symbol].last_order_id
+        if self.props[symbol]['stoploss_id']:
             try:
                 res = self.client.client.Order.Order_getOrders(
                     filter=json.dumps({"symbol": symbol, "open": True})).result()
-                if self.props[symbol].stoploss_id in [order['clOrdID'] for order in res[0]]:
+                if self.props[symbol]['stoploss_id'] in [order['clOrdID'] for order in res[0]]:
                     print("Bot order open, stoploss might be modified", flush=True)
                     self.modifiy_stop(symbol, sl)
-                    self.props[symbol].entry = entry
-                    self.props[symbol].open = True
+                    self.props[symbol]['entry'] = entry
+                    self.props[symbol]['open'] = True
             except HTTPBadRequest as e:
                 print("Error getting orders.", e)
 
     def save_open_id(self, symbol, id):
-        self.props[symbol].stoploss_id = id
+        self.props[symbol]['stoploss_id'] = id
         settings = pickle.load(open(self._settings_path, 'rb'))
         settings.symbols[symbol].last_order_id = id
         pickle.dump(settings, file=open(self._settings_path, 'wb'))
@@ -135,33 +138,33 @@ class BitmexOrder:
     def manage_entries(self, symbols):
         for symbol in symbols:
             cp = self.client.get_current_price(symbol)
-            if self.props[symbol].wait_stop:
+            if self.props[symbol]['wait_stop']:
                 time.sleep(0.5)
-                if self.props[symbol].qty > 0 and cp >= self.props[symbol].entry and self.client.open_contracts(symbol) != 0:
-                    self.props[symbol].wait_stop = False
-                    self.props[symbol].open = True
+                if self.props[symbol]['qty'] > 0 and cp >= self.props[symbol]['entry'] and self.client.open_contracts(symbol) != 0:
+                    self.props[symbol]['wait_stop'] = False
+                    self.props[symbol]['open'] = True
                     print("Long Position has been opened, amending Stoploss to",
-                          self.props[symbol].SL, flush=True)
+                          self.props[symbol]['SL'], flush=True)
                     self.stoploss_order(symbol)
-                elif self.props[symbol].qty < 0 and cp <= self.props[symbol].entry and self.client.open_contracts(symbol) != 0:
-                    self.props[symbol].wait_stop = False
-                    self.props[symbol].open = True
+                elif self.props[symbol]['qty'] < 0 and cp <= self.props[symbol]['entry'] and self.client.open_contracts(symbol) != 0:
+                    self.props[symbol]['wait_stop'] = False
+                    self.props[symbol]['open'] = True
                     print("Short Position has been opened, amending Stoploss to",
-                          self.props[symbol].SL, flush=True)
+                          self.props[symbol]['SL'], flush=True)
                     self.stoploss_order(symbol)
-            elif self.props[symbol].open:
-                if self.props[symbol].qty > 0 and cp <= self.props[symbol].SL and self.client.open_contracts(symbol) == 0:
-                    self.props[symbol].open = False
-                    self.props[symbol].qty = 0
+            elif self.props[symbol]['open']:
+                if self.props[symbol]['qty'] > 0 and cp <= self.props[symbol]['SL'] and self.client.open_contracts(symbol) == 0:
+                    self.props[symbol]['open'] = False
+                    self.props[symbol]['qty'] = 0
                     print("Long Position closed. {} Contracts from {} to {}. PnL in Points: {}".format(
-                        self.props[symbol].qty, self.props[symbol].entry, self.props[symbol].SL, self.price_decimals(symbol, cp-self.props[symbol].entry)), flush=True)
-                elif self.props[symbol].qty < 0 and cp >= self.props[symbol].SL and self.client.open_contracts(symbol) == 0:
-                    self.props[symbol].open = False
-                    self.props[symbol].qty = 0
+                        self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
+                elif self.props[symbol]['qty'] < 0 and cp >= self.props[symbol]['SL'] and self.client.open_contracts(symbol) == 0:
+                    self.props[symbol]['open'] = False
+                    self.props[symbol]['qty'] = 0
                     print("Short Position closed. {} Contracts from {} to {}. PnL in Points: {}".format(
-                        -self.props[symbol].qty, self.props[symbol].entry, self.props[symbol].SL, self.price_decimals(symbol, cp-self.props[symbol].entry)), flush=True)
+                        -self.props[symbol]['qty'], self.props[symbol]['entry'], self.props[symbol]['SL'], self.price_decimals(symbol, cp-self.props[symbol]['entry'])), flush=True)
                 else:
-                    self.props[symbol].open = False
+                    self.props[symbol]['open'] = False
 
     def generate_id(self, symbol, _type='stop'):
         return "{}_{}_{}_{}".format(self.magic, symbol, str(uuid.uuid4().fields[-1])[:5], _type)
@@ -201,12 +204,12 @@ class BitmexOrder:
 
     def stoploss_order(self, symbol, execPrice='LastPrice'):
         try:
-            self.props[symbol].stoploss_id = self.generate_id(
+            self.props[symbol]['stoploss_id'] = self.generate_id(
                 symbol, _type='SL')
-            self.save_open_id(symbol, self.props[symbol].stoploss_id)
+            self.save_open_id(symbol, self.props[symbol]['stoploss_id'])
             return self.client.client.Order.Order_new(
-                symbol=self.symbol, ordType='Stop', clOrdID=self.StoplossID, orderQty=-self.props[symbol].qty,
-                stopPx=self.price_decimals(symbol, self.props[symbol].SL), execInst=execPrice
+                symbol=self.symbol, ordType='Stop', clOrdID=self.StoplossID, orderQty=-self.props[symbol]['qty'],
+                stopPx=self.price_decimals(symbol, self.props[symbol]['SL']), execInst=execPrice
             ).result()
         except HTTPBadRequest as e:
             print("Error placing stoploss order.", e, flush=True)
@@ -222,7 +225,7 @@ class BitmexOrder:
             print("Error canceling order.", e, flush=True)
 
     def stoploss_cancel(self, symbol):
-        self.order_cancel(self.props[symbol].stoploss_id)
+        self.order_cancel(self.props[symbol]['stoploss_id'])
 
     def stoporder_cancel(self, symbol):
         self.order_cancel(self.props[symbol].stop_id)
@@ -234,11 +237,11 @@ class BitmexOrder:
                 symbol=symbol, ordType='Stop', clOrdID=self.props[symbol].stop_id, orderQty=orderQty,
                 stopPx=self.price_decimals(symbol, entry), execInst='LastPrice'
             ).result()
-            self.props[symbol].qty = orderQty
+            self.props[symbol]['qty'] = orderQty
             self.props[symbol].wait_stop = True
-            self.props[symbol].SL = sl
-            self.props[symbol].TP = tp
-            self.props[symbol].entry = entry
+            self.props[symbol]['SL'] = sl
+            self.props[symbol]['TP'] = tp
+            self.props[symbol]['entry'] = entry
             return order_res
         except HTTPBadRequest as e:
             print("Error placing bracket stop order in {}.".format(
@@ -247,12 +250,12 @@ class BitmexOrder:
     def bracket_market_order(self, symbol, orderQty, sl, tp=0):
         try:
             entry = self.market_order(symbol, orderQty)
-            self.props[symbol].SL = sl
-            self.props[symbol].TP = tp
+            self.props[symbol]['SL'] = sl
+            self.props[symbol]['TP'] = tp
             time.sleep(5)
             stoploss = self.stoploss_order(symbol)
-            self.props[symbol].qty = orderQty
-            self.props[symbol].open = True
+            self.props[symbol]['qty'] = orderQty
+            self.props[symbol]['open'] = True
             return entry, stoploss
         except HTTPBadRequest as e:
             print("Error placing bracket market order in {}.".format(
@@ -263,8 +266,8 @@ class BitmexOrder:
             order_res = self.client.client.Order.Order_new(
                 symbol=symbol, ordType='Market', orderQty=orderQty
             ).result()
-            self.props[symbol].qty = orderQty
-            self.props[symbol].open = True
+            self.props[symbol]['qty'] = orderQty
+            self.props[symbol]['open'] = True
             return order_res
         except HTTPBadRequest as e:
             print("Error placing market order.", e, flush=True)
@@ -273,7 +276,7 @@ class BitmexOrder:
         if self.props[symbol].wait_stop:
             try:
                 res = self.client.client.Order.Order_amend(
-                    orderID=self.props[symbol].stoploss_id, stopPx=self.price_decimals(symbol,
+                    orderID=self.props[symbol]['stoploss_id'], stopPx=self.price_decimals(symbol,
                                                                                        newPrice)
                 ).result()
                 return res
@@ -289,8 +292,8 @@ class BitmexOrder:
 
     def close(self, symbol, qty=0):
         if not qty:
-            qty = -self.props[symbol].qty
-        if self.props[symbol].open:
+            qty = -self.props[symbol]['qty']
+        if self.props[symbol]['open']:
             try:
                 return self.client.client.Order.Order_new(
                     symbol=symbol, ordType='Market', execInst='Close', orderQty=qty
