@@ -65,7 +65,7 @@ def file_create_input(check_exist=True, symbols=['XBTUSD'], broker='bitmex', str
 
 
 def make_pickle_file(filename, token, api_key, api_secret, symbol_settings):
-    settings = BrokerSettings
+    settings = BrokerSettings()
     settings.token = token
     settings.api_key = api_key
     settings.api_secret = api_secret
@@ -99,7 +99,7 @@ def check_settings(settings, symbols, broker, strategy):
                    "\n\tAPI ID: {}"
                    "\n\tAPI Secret: ...{}"
                    "{}"
-                   "Do you want to continue? ['y' for yes, 'n' for no, 'c' for"
+                   "\n\t\tDo you want to continue? ['y' for yes, 'n' for no, 'c' for"
                    " change settings] "
                    .format(settings.token[:4], settings.api_key, settings.api_secret[-4:], position_symbol_sizes(settings.symbols)))
         if qr == '' or qr[0].lower() not in ['y', 'n', 'c']:
